Cross-contract obligation coverage report.
Analyzes a set of contracts (optionally with a binding registry) to compute how many proof obligations are backed by falsification tests, Kani harnesses, and implementation bindings.
Structs
- Contract
Coverage - Coverage details for a single contract.
- Coverage
Report - Coverage report across multiple contracts.
- Coverage
Totals - Aggregate totals across all contracts.
Functions
- coverage_
report - Compute a coverage report for a set of contracts.
- overall_
percentage - Compute overall obligation coverage percentage.