coverage_report

Function coverage_report 

pub fn coverage_report(
    contracts: &[(String, &Contract)],
    binding: Option<&BindingRegistry>,
) -> CoverageReport
Compute a coverage report for a set of contracts.

If a binding registry is provided, binding coverage is included. Otherwise binding fields are zero.