pub fn diff_contracts(old: &Contract, new: &Contract) -> ContractDiffExpand description
Diff two contracts and produce a structured change report.
pub fn diff_contracts(old: &Contract, new: &Contract) -> ContractDiffDiff two contracts and produce a structured change report.