pub fn obligation_pattern(ot: ObligationType) -> &'static strExpand description
Return a mathematical pattern description for the given obligation type.
pub fn obligation_pattern(ot: ObligationType) -> &'static strReturn a mathematical pattern description for the given obligation type.