Module generate

Module generate 

End-to-end codegen — generates all artifacts to disk.

Combines scaffold, kani, and probar generators into a single operation that writes files to a target directory.

Structs

GeneratedFile
A single generated file.
GeneratedFiles
Manifest of generated files.

Enums

ArtifactKind
The kind of generated artifact.

Functions

generate_all
Generate all artifacts from a contract and write to output_dir.