Module graph

Module graph 

Contract dependency graph — composition via depends_on.

Builds a directed acyclic graph (DAG) of contract dependencies and provides cycle detection and topological ordering.

Structs

DependencyGraph
A dependency graph of contracts.
GraphNode
A single node in the graph with metadata.

Functions

dependency_graph
Build a dependency graph from a set of contracts.
graph_nodes
Get metadata about each node in the graph.