ContractIndex

Struct ContractIndex 

pub struct ContractIndex {
    pub entries: Vec<ContractEntry>,
    /* private fields */
}
In-memory contract index with inverted indexes for fast lookup.

Fields

entries: Vec<ContractEntry>

Implementations

Source

impl ContractIndex

pub fn from_directory(dir: &Path) -> Result<Self, Box<dyn Error>>

Build an index from a directory of YAML contracts.

Uses cached index from .pv/contracts.idx when fresh, otherwise rebuilds and caches for next time.

pub fn from_directory_opts( dir: &Path, force_rebuild: bool, ) -> Result<Self, Box<dyn Error>>

Build an index with option to force rebuild (skip cache).

pub fn build_from_directory(dir: &Path) -> Result<Self, Box<dyn Error>>

Build an index from a directory without cache.

pub fn from_entries(entries: Vec<ContractEntry>) -> Self

Build an index from pre-parsed entries.

pub fn get_by_stem(&self, stem: &str) -> Option<&ContractEntry>

Look up a contract by exact stem.

pub fn cached_score(&self, stem: &str) -> Option<f64>

Get the pre-computed composite score for a contract stem.

pub fn cached_pagerank(&self, stem: &str) -> Option<f64>

Get the pre-computed pagerank score for a contract stem.

pub fn get_by_obligation(&self, ob_type: &str) -> Vec<&ContractEntry>

Look up contracts by obligation type.

pub fn get_by_equation(&self, eq: &str) -> Vec<&ContractEntry>

Look up contracts by equation name.

BM25 search across all entries. Returns (index, score) pairs sorted descending.

Regex search across all entries. Returns matching indices.

Literal substring search. Returns matching indices.

pub fn depended_by(&self, stem: &str) -> Vec<&str>

Return reverse dependencies: contracts that depend on stem.

pub fn pagerank(&self, iterations: usize, damping: f64) -> HashMap<String, f64>

Compute pagerank scores over the contract dependency graph.

Returns a map from stem to pagerank score. Higher scores indicate more “important” contracts (more depended-upon by others).