pub fn reverse_coverage(
crate_dir: &Path,
binding_path: &Path,
) -> ReverseCoverageReportExpand description
Scan a crate directory for pub fn declarations and diff against binding.yaml.
pub fn reverse_coverage(
crate_dir: &Path,
binding_path: &Path,
) -> ReverseCoverageReportScan a crate directory for pub fn declarations and diff against binding.yaml.