Module scaffold

Module scaffold 

Scaffold generator โ€” Phase 3 of the pipeline.

Generates Rust trait definitions and failing test stubs from parsed YAML contracts.

Functions

generate_contract_tests
Generate failing contract test stubs from a contract.
generate_standalone_trait
Generate a standalone, named contract trait from a YAML contract.
generate_trait
Generate a Rust trait definition from a contract.