Module coverage

Module coverage 

Cross-contract obligation coverage report.

Analyzes a set of contracts (optionally with a binding registry) to compute how many proof obligations are backed by falsification tests, Kani harnesses, and implementation bindings.

Structs

ContractCoverage
Coverage details for a single contract.
CoverageReport
Coverage report across multiple contracts.
CoverageTotals
Aggregate totals across all contracts.

Functions

coverage_report
Compute a coverage report for a set of contracts.
overall_percentage
Compute overall obligation coverage percentage.