End-to-end codegen — generates all artifacts to disk.
Combines scaffold, kani, and probar generators into a single operation that writes files to a target directory.
Structs
- Generated
File - A single generated file.
- Generated
Files - Manifest of generated files.
Enums
- Artifact
Kind - The kind of generated artifact.
Functions
- generate_
all - Generate all artifacts from a contract and write to
output_dir.